searchNodes=[{"ref":"EctoAutoslugField.html","title":"EctoAutoslugField","type":"module","doc":"Autoslug field for Ecto."},{"ref":"EctoAutoslugField.Slug.html","title":"EctoAutoslugField.Slug","type":"module","doc":"This module defines all the required functions and modules to work with. Examples To create a simple &#39;Slug&#39; field do: defmodule MyCustomSlug do use EctoAutoslugField.Slug, from: :name_field, to: :slug_field end It is also possible to override get_sources/2 and build_slug/2 functions which are part of the AutoslugField&#39;s API. More complex example with the optional sources and custom slug generation function: defmodule MyComplexSlug do use EctoAutoslugField.Slug, to: :slug_field def get_sources(changeset, _opts) do basic_fields = [:name, :surname] if is_company_info_set(changeset) do # We want to track changes in the person&#39;s company: basic_fields ++ [:company, :position] else basic_fields end end def build_slug(sources, changeset) do super(sources, changeset) # Calls the `SlugGenerator.build_slug/1` |&gt; String.replace(&quot;-&quot;, &quot;+&quot;) end end It is also possible to always change your slug, even if it was already set: defmodule ThisSlugShouldChange do use EctoAutoslugField.Slug, from: :some_field, to: :slug_field, always_change: true end If you want to change slug for only one instance without setting always_change option, use force_generate_slug/1 function: defmodule SimpleSlugForce do use EctoAutoslugField.Slug, from: :name, to: :some_slug end Then you can use SimpleSlugForce.force_generate_slug(changeset) for any instances, that needs to recreate slugs for some reason. Be careful with these options, since cool URIs do not change."},{"ref":"EctoAutoslugField.SlugBase.html","title":"EctoAutoslugField.SlugBase","type":"module","doc":"This module defines all functions Slug module uses."},{"ref":"EctoAutoslugField.SlugBase.html#build_slug/2","title":"EctoAutoslugField.SlugBase.build_slug/2","type":"function","doc":"This function is used to build the slug itself. This function is a place to modify the result slug. For convenience you can call super(sources, changeset) which will return the slug binary. super(sources) uses Slugger, but you can completely change slug-engine to your own. Note: this function will only be called if sources is not empty. Also important this function will be called only once for the normal workflow. And every time for :always_change. So you can do some heavy computations. If for some reason slug should not be set - just return nil or empty binary. It should return a binary or nil."},{"ref":"EctoAutoslugField.SlugBase.html#get_sources/2","title":"EctoAutoslugField.SlugBase.get_sources/2","type":"function","doc":"This function is used to get sources for the slug. There can be many usecases when this behavior is required, here are the brief examples: Conditional slug sources Add any data from different sources This function should return list of atoms or binaries, or nil. When processing the returned list: atom-key is supposed to identify the model field binary-key is treated as a data itself, it won&#39;t be changed"},{"ref":"EctoAutoslugField.SlugBase.html#maybe_generate_slug/3","title":"EctoAutoslugField.SlugBase.maybe_generate_slug/3","type":"function","doc":"This function is used to generate slug. It is called &#39;maybe&#39; since it may not generate slug for several reasons: It was already created and :always_change option was not set The source fields for the slug were empty This function takes changeset as an input and returns changeset."},{"ref":"EctoAutoslugField.SlugBase.html#unique_constraint/3","title":"EctoAutoslugField.SlugBase.unique_constraint/3","type":"function","doc":"This is just a helper function to check for uniqueness. It basically just wraps Ecto.Changeset and set a proper field name."},{"ref":"EctoAutoslugField.SlugGenerator.html","title":"EctoAutoslugField.SlugGenerator","type":"module","doc":"This module works with slugs itself. It is just a wrapper around &#39;Slugger&#39;. It is suited for inner use."},{"ref":"EctoAutoslugField.SlugGenerator.html#build_slug/2","title":"EctoAutoslugField.SlugGenerator.build_slug/2","type":"function","doc":"This is a public wrapper around do_build_slug/1 functions. Default slug builder."},{"ref":"EctoAutoslugField.SlugGenerator.html#maybe_generate_slug/3","title":"EctoAutoslugField.SlugGenerator.maybe_generate_slug/3","type":"function","doc":"This function conditionally generates slug. This function prepares sources and then calls do_generate_slug/3."},{"ref":"EctoAutoslugField.Type.html","title":"EctoAutoslugField.Type","type":"module","doc":"This module represents a simple wrapper around &#39;:string&#39; Ecto type."},{"ref":"EctoAutoslugField.Type.html#cast/1","title":"EctoAutoslugField.Type.cast/1","type":"function","doc":"Casts the given input to the custom type. This callback is called on external input and can return any type, as long as the dump/1 function is able to convert the returned value into an Ecto native type. There are two situations where this callback is called: When casting values by Ecto.Changeset When passing arguments to Ecto.Query When returning {:error, keyword()}, the returned keyword list will be preserved in the changeset errors, similar to Changeset.add_error/4. Passing a :message key, will override the default message. It is not possible to override the :type key. For {:array, CustomType} or {:map, CustomType} the returned keyword list will be erased and the default error will be shown. Callback implementation for Ecto.Type.cast/1."},{"ref":"EctoAutoslugField.Type.html#dump/1","title":"EctoAutoslugField.Type.dump/1","type":"function","doc":"Dumps the given term into an Ecto native type. This callback is called with any term that was stored in the struct and it needs to validate them and convert it to an Ecto native type. Callback implementation for Ecto.Type.dump/1."},{"ref":"EctoAutoslugField.Type.html#embed_as/1","title":"EctoAutoslugField.Type.embed_as/1","type":"function","doc":"Dictates how the type should be treated inside embeds. By default, the type is sent as itself, without calling dumping to keep the higher level representation. But it can be set to :dump to it is dumped before encoded. Callback implementation for Ecto.Type.embed_as/1."},{"ref":"EctoAutoslugField.Type.html#equal?/2","title":"EctoAutoslugField.Type.equal?/2","type":"function","doc":"Checks if two terms are semantically equal. Callback implementation for Ecto.Type.equal?/2."},{"ref":"EctoAutoslugField.Type.html#load/1","title":"EctoAutoslugField.Type.load/1","type":"function","doc":"Loads the given term into a custom type. This callback is called when loading data from the database and receives an Ecto native type. It can return any type, as long as the dump/1 function is able to convert the returned value back into an Ecto native type. Callback implementation for Ecto.Type.load/1."},{"ref":"EctoAutoslugField.Type.html#type/0","title":"EctoAutoslugField.Type.type/0","type":"function","doc":"Returns the underlying schema type for the custom type. For example, if you want to provide your own date structures, the type function should return :date. Note this function is not required to return Ecto primitive types, the type is only required to be known by the adapter. Callback implementation for Ecto.Type.type/0."},{"ref":"readme.html","title":"EctoAutoslugField","type":"extras","doc":"EctoAutoslugField ecto_autoslug_field is a reusable Ecto library which can automatically create slugs from other fields. We use slugger as a default slug-engine. We only depend on the ecto package (we do not deal with ecto_sql at all). We support ecto &gt;= 2.1 and ecto &lt; 4! See this blog post for more information."},{"ref":"readme.html#installation","title":"EctoAutoslugField - Installation","type":"extras","doc":"def deps do [ {:ecto_autoslug_field, &quot;~&gt; 2.0&quot;} ] end"},{"ref":"readme.html#options","title":"EctoAutoslugField - Options","type":"extras","doc":"There are several options to configure. Required: :to - represents the slug field name where to save value to Optional: :from - represents the source fields from which to build slug, if this option is not set you have to override get_sources/2 function :always_change - if this option is set slug will be recreated from the given sources each time maybe_generate_slug function is called"},{"ref":"readme.html#functions","title":"EctoAutoslugField - Functions","type":"extras","doc":"get_sources/2 - this function is used to get sources for the slug, docs. build_slug/2 - this function is a place to modify the result slug, docs."},{"ref":"readme.html#examples","title":"EctoAutoslugField - Examples","type":"extras","doc":"The simplest example: defmodule EctoSlugs.Blog.Article.TitleSlug do use EctoAutoslugField.Slug, from: :title, to: :slug end defmodule EctoSlugs.Blog.Article do use Ecto.Schema import Ecto.Changeset alias EctoSlugs.Blog.Article alias EctoSlugs.Blog.Article.TitleSlug schema &quot;blog_articles&quot; do field :breaking, :boolean, default: false field :content, :string field :title, :string field :slug, TitleSlug.Type timestamps() end def changeset(%Article{} = article, attrs) do article |&gt; cast(attrs, [:title, :content, :breaking]) |&gt; validate_required([:title, :content]) |&gt; unique_constraint(:title) |&gt; TitleSlug.maybe_generate_slug |&gt; TitleSlug.unique_constraint end end See this tutorial for some more examples."},{"ref":"readme.html#changelog","title":"EctoAutoslugField - Changelog","type":"extras","doc":"See CHANGELOG.md."},{"ref":"readme.html#license","title":"EctoAutoslugField - License","type":"extras","doc":"MIT. Please see LICENSE for licensing details."}]